==> yonderbox-graphql-mongodb-adapter-1.0.48.tgz: package/lib/adapterCache.js <==
const client = require('prom-client')
const pkg = require('../package.json')
const _ = require('lodash')

const yves = require('yves')

const debugCache = yves.debugger(`${pkg.name.replace(/-/g,':')}:cache`)

const util = require('./util')

const cacheInvalidationTTL = ((1000 * 60) * 3) // 3 minutes
const cacheInvalidationCleanupInterval = 5 * 1000

const { MongoClient } = require('mongodb')

let AdapterDataSources
let mongoClient

const config = {
  enabled: true,
  url: 'mongodb://localhost:3001',
  db: 'adapter',
  collection: 'cache',
  options: {
    keepAlive: 1,
    connectTimeoutMS: 30000,
    reconnectTries: 30,
    reconnectInterval: 1000,
  },
}


function initialize() {
  if (!mongoClient) {
    connectMongodb(config)
  }
}

async function connectMongodb(options) {
  if (mongoClient) {
    return mongoClient
  } else {
    mongoClient = new MongoClient(options.url,Object.assign({ useNewUrlParser: true, useUnifiedTopology: true},options.options))
    return await mongoClient.connect().then( d => {
      debug('adapterCache MongoDB connected')
      return d
    }).catch( e => {
      debug('adapterCache MongoDB connect exceptions: %y',e)
    })
  }
}

function setup(collection,field) {
  initialize()
  return {
    get(key) {
      debugCache('get %y',key)

      return mongoClient.db(config.db)
        .collection(collection)
        .findOne({_id:key})
        .then( row => row && row[field || 'value'] )
    },
    set(key,value) {
      debugCache('set %y = %y',key,value)
      return mongoClient.db(config.db)
        .collection(collection)
        .updateOne({_id:key},{$set:{[field || 'value']:value,timestamp:new Date()}},{upsert: true })
    },
  }
}

module.exports = {
  setup,
}

/*


const createSHA = require('crypto').createHash('sha256')

function computeQueryHash(query) {
    return createSHA.update(query).digest('hex')
}

*/

==> yonderbox-graphql-mongodb-adapter-1.0.50.tgz: package/lib/adapterCache.js <==
const pkg = require('../package.json')

const yves = require('yves')

const debugCache = yves.debugger(`${pkg.name.replace(/-/g,':')}:cache`)

const { MongoClient } = require('mongodb')

let mongoClient

const config = {
  enabled: true,
//  url: 'mongodb://localhost:3001',
  db: 'adapter',
  collection: 'cache',
  options: {
    keepAlive: 1,
    connectTimeoutMS: 30000,
//    reconnectTries: 30,
//    reconnectInterval: 1000,
  },
}

function setConfig(obj) {
  if (obj.url) config.url = obj.url
}


function initialize() {
  if (!mongoClient) {
    connectMongodb(config)
  }
}

async function connectMongodb(options) {
  if (mongoClient) {
    return mongoClient
  } else {
    mongoClient = new MongoClient(options.url,Object.assign({ useNewUrlParser: true, useUnifiedTopology: true},options.options))
    return await mongoClient.connect().then( d => {
      debug('adapterCache MongoDB connected')
      return d
    }).catch( e => {
      debug('adapterCache MongoDB connect exceptions: %y',e)
    })
  }
}

function setup(collection,field) {
  initialize()
  return {
    get(key) {
      debugCache('get %y',key)

      return mongoClient.db(config.db)
        .collection(collection)
        .findOne({_id:key})
        .then( row => row && row[field || 'value'] )
    },
    set(key,value) {
      debugCache('set %y = %y',key,value)
      return mongoClient.db(config.db)
        .collection(collection)
        .updateOne({_id:key},{$set:{[field || 'value']:value,timestamp:new Date()}},{upsert: true })
    },
  }
}

module.exports = {
  setConfig,
  setup,
}

/*


const createSHA = require('crypto').createHash('sha256')

function computeQueryHash(query) {
    return createSHA.update(query).digest('hex')
}

*/
